/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__LCD_H__)
#define __LCD_H__

/*
 * Drag in some common headers
 */

#include <stdio.h>
#include <stdlib.h>

#if defined(_WIN32)
#   define WIN32_LEAN_AND_MEAN
#   include <windows.h>
#   include "pthread_w32.h"
#else
#   include <unistd.h>
#   include <pthread.h>
#endif

/*
 * Setup some common useful DLL linkage macros
 */

#if defined(_WIN32)
#   if defined(__cplusplus)
#       define LCD_API extern "C" _declspec(dllexport)
#   else
#       define LCD_API _declspec(dllexport)
#   endif
#else
#   if defined(__cplusplus)
#       define LCD_API extern "C"
#   else
#       define LCD_API
#   endif
#endif

/*
 * Our typedefs
 */

/****************************************************************************
 *                                                                          *
 *                                                                          *
 *                                                                          *
 ****************************************************************************/


typedef struct _tag_colour
{
    unsigned char red;
    unsigned char green;
    unsigned char blue;

} COLOUR, * LPCOLOUR;

#define SET_COLOUR(c,r,g,b) c->red = (r); c->green = (g); c->blue = (b);


/*
 * Useful way of suspending a process for a given number of milliseconds
 */

#if defined(_WIN32)
#   define SLEEP(x) Sleep(x)
#else
#   define SLEEP(x) usleep((x) * 1000)
#endif



#define IILC_ASSERT(x) if (!(x)) { \
    printf("Assertion '%s' failed in file %s:%d\n", #x, __FILE__, __LINE__); \
    abort(); }


#define ERR_MEM_ALLOC_FAILED                        0x01
#define ERR_MEM_FREE_FAILED                         0x02
#define ERR_END_OF_PACKET                           0x03
#define ERR_PACKET_FULL                             0x04
#define ERR_BAD_PARAMETER                           0x05
#define ERR_INVALID_DEVICE                          0x06
#define ERR_INSUFFICIENT_DATA                       0x07
#define ERR_BUFFER_TOO_SMALL                        0x08
#define ERR_INVALID_CONFIG                          0x09
#define ERR_OBJECT_NOT_FOUND                        0x0A
#define ERR_NOT_IMPLEMENTED                         0x0B
#define ERR_MUTEX_LOCK_FAILED                       0x0C
#define ERR_MUTEX_UNLOCK_FAILED                     0x0D



#endif /* __LCD_H__ */
