/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__TRACE_H__)
#define __TRACE_H__

#include "lcd.h"

typedef struct _tag_trace_context_data
{
    int module;

    int function;

    char * pszFunction;

} traceContextData;

/*
 * Entry and exit macros. Arranged like this because macros with var-length args
 * are not portable.
 */

extern unsigned char g_bSev0Enabled;
extern unsigned char g_bSev1Enabled;
extern unsigned char g_bSev2Enabled;
extern unsigned char g_bSev3Enabled;
extern unsigned char g_bSev4Enabled;
extern unsigned char g_bSev5Enabled;


#define IILC_TRACE_CONTEXT  &tData

#define IILC_TRACE_ENTRY(mod,func)      \
    traceContextData tData;             \
    tData.module = (mod);               \
    tData.function = (func);            \
    tData.pszFunction = #func;          \
    traceEntry(&tData);

#define IILC_TRACE_EXIT                 \
    traceExit(IILC_TRACE_CONTEXT)

/* Exit with a return code */
#define IILC_TRACE_EXIT_RC(r)  \
    traceDebug(IILC_TRACE_CONTEXT, "rc %d (0x%02X)", r, r); \
    IILC_TRACE_EXIT


#define IILC_TRACE_DEBUG(x)             traceDebug x
#define IILC_TRACE_INFO(x)              traceInfo x
#define IILC_TRACE_WARNING(x)           traceWarning x
#define IILC_TRACE_ERROR(x)             traceError x


LCD_API void traceDebug(traceContextData * pContext,
                        char * fmt,
                        ...);

LCD_API void traceInfo(traceContextData * pContext,
                       char * fmt,
                       ...);

LCD_API void traceWarning(traceContextData * pContext,
                          char * fmt, 
                          ...);

LCD_API void traceError(traceContextData * pContext,
                        char * fmt, 
                        ...);

LCD_API void traceEntry(traceContextData * pContext);

LCD_API void traceExit(traceContextData * pContext);


/*
 * Defines to handle 
 */


#define T_dispatchReportPacket          0x01
#define T_displaySetLED                 0x02
#define T_displaySetLEDController       0x03
#define T_TxThread                      0x04
#define T_displayReceiveFanSpeedReport  0x05
#define T_displayReceiveKeyPressReport  0x06
#define T_processConfigDevice           0x07
#define T_processConfigDisplay          0x08
#define T_configGetDeviceCount          0x09
#define T_configGetModuleCount          0x0A
#define T_configGetDeviceClass          0x0B
#define T_processConfigFile             0x0C
#define T_configGetDevicePort           0x0D
#define T_deviceCreate                  0x0E
#define T_parserBeginDisplay            0x0F
#define T_configGetDisplayCount         0x10
#define T_deviceStart                   0x11
#define T_displayStart                  0x12
#define T_deviceWritePacket             0x13
#define T_displayCallbackFan            0x14
#define T_configGetModuleName           0x15
#define T_parserBeginModule             0x16
#define T_parserEndModule               0x17
#define T_parserEndDisplay              0x18
#define T_parserEndDevice               0x19
#define T_parserSetModuleLibrary        0x1A
#define T_moduleInit                    0x1B
#define T_parserBeginDevice             0x1C
#define T_parserParse                   0x1D
#define T_vectorCreate                  0x1E
#define T_vectorAdd                     0x1F
#define T_parserGetCurrentFile        0x20
#define T_parserModuleControlObject     0x21
#define T_main                          0x22
#define T_packetCreate                  0x23
#define T_parserDeviceUseFan            0x24
#define T_parserDeviceFindObject        0x25
#define T_parserDeviceCreateObject      0x26
#define T_parserModuleReportObject      0x27
#define T_parserModuleVirtualObject     0x28
#define T_displayCreate                 0x29
#define T_driver_Create                 0x2A
#define T_cfontz_InitDevice             0x2B
#define T_cfontz_InitDevice_unix        0x2C
#define T_cfontz_InitDevice_w32         0x2D
#define T_parserDeviceUseLED            0x2E
#define T_cfontz_InitDeviceType         0x2F
#define T_cfontz_UpdateTempReport       0x30
#define T_parserBeginScreen             0x31
#define T_parserEndScreen               0x32
#define T_fanSpeedReport                0x33
#define T_driver_SetFanPower            0x34
#define T_displayCallbackTemp           0x35
#define T_parserDeviceUseTemp           0x36
#define T_cfontz_ReceiveTempReport      0x37
#define T_temperatureReport             0x38
#define T_vectorSetElementAt            0x39
#define T_parserDeviceObjectUse         0x3A
#define T_parserGetContext              0x3B
#define T_parserDeviceSetPort           0x3C
#define T_parserGetCurrentConfig        0x3D


/*
 * Useful defines to allow consistent formatting of values.
 */

#define T_FMT_PTR           "%p"
#define T_FMT_UINT          "%u"
#define T_FMT_INT           "%d"
#define T_FMT_SIZET         "%u"
#define T_FMT_DOUBLE        "%f"


/*
 * Display module defines
 */

typedef enum _tag_enum_module {

    MODULE_TYPE_DISPLAY   = 0,
    MODULE_TYPE_PACKET    = 1,
    MODULE_TYPE_APP       = 2

} MODULE_TYPE;


#endif /* __TRACE_H__ */



