/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__PTHREAD_W32_H__)
#define __PTHREAD_W32_H__

#define pthread_mutex_t int

#define pthread_once_t int

#define PTHREAD_ONCE_INIT 0

#define pthread_key_t int

#define pthread_t int

#define pthread_cond_t int

#define pthread_attr_t int

#define pthread_condattr_t int

#define pthread_mutexattr_t int 

#define PTHREAD_MUTEX_INITIALIZER 0

#define PTHREAD_COND_INITIALIZER 0

#define ETIMEDOUT 1

/****************************************************************************
 *                                                                          *
 *                            SEMAPHORE FUNCTIONS                           *
 *                                                                          *
 ****************************************************************************/

int pthread_cond_init(pthread_cond_t * cond,
                      const pthread_condattr_t * attr);

int pthread_cond_destroy(pthread_cond_t * cond);

int pthread_cond_broadcast(pthread_cond_t *cond);

int pthread_cond_signal(pthread_cond_t *cond);

int pthread_cond_timedwait(pthread_cond_t * cond,
                           pthread_mutex_t * mutex,
                           const struct timespec * abstime);

int pthread_cond_wait(pthread_cond_t * cond,
                      pthread_mutex_t * mutex);

/****************************************************************************
 *                                                                          *
 *                              MUTEX FUNCTIONS                             *
 *                                                                          *
 ****************************************************************************/

int pthread_mutex_init(pthread_mutex_t * mutex,
                       const pthread_mutexattr_t * attr);

int pthread_mutex_destroy(pthread_mutex_t * mutex);

int pthread_mutex_lock(pthread_mutex_t * mutex);

int pthread_mutex_trylock(pthread_mutex_t * mutex);

int pthread_mutex_unlock(pthread_mutex_t * mutex);

int pthread_once(pthread_once_t * once_control,
                 void (*init_routine)(void));


/****************************************************************************
 *                                                                          *
 *                               TLS FUNCTIONS                              *
 *                                                                          *
 ****************************************************************************/

int pthread_key_create(pthread_key_t * key,
                       void (*destructor)(void*));

void * pthread_getspecific(pthread_key_t key);

int pthread_setspecific(pthread_key_t key, 
                        const void *value);


/****************************************************************************
 *                                                                          *
 *                              THREAD FUNCTIONS                            *
 *                                                                          *
 ****************************************************************************/

int pthread_create(pthread_t * thread,
                   const pthread_attr_t * attr,
                   void * (*start_routine)(void *),
                   void * arg);

int pthread_join(pthread_t thread,
                 void ** value_ptr);


#endif /* __PTHREAD_W32_H__ */

