/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#include <dlfcn.h>
#include <errno.h>
#include <fcntl.h>
#include <pthread.h>
#include <string.h>
#include <termios.h>
#include <time.h>
#include <unistd.h>
#include <sys/select.h>
#include <sys/time.h>

#include "trace.h"
#include "cfontz.h"



#define IILC_MODULE MODULE_TYPE_APP


int cfontz_InitDevice(LP_CFONTZ_DEV_INSTANCE pInst)
{
    int rc = 0;

	struct termios portset;	

    IILC_TRACE_ENTRY(IILC_MODULE, T_cfontz_InitDevice_unix);

    /* Open the USB serial port */
    pInst->Device = open(pInst->pszPort, O_RDWR | O_NOCTTY | O_NDELAY);
	if (pInst->Device == -1) {
        traceError(IILC_TRACE_CONTEXT, "Could not open port [%s]: %s (%d)", 
            pInst->pszPort, strerror(errno), errno);
		rc = 1;
		goto end_of_function;
	}

	if (tcgetattr(pInst->Device, &portset) == -1) {
		traceDebug(IILC_TRACE_CONTEXT, "tcgetattr() failed: %s", strerror(errno));
		rc = 1;
		goto end_of_function;
	}

	cfmakeraw(&portset);
	portset.c_cflag |= 0;
	cfsetispeed(&portset, B115200);
	cfsetospeed(&portset, B115200);
	if (tcsetattr(pInst->Device, TCSANOW, &portset) == -1) {
		printf("tcsetattr() failed: %s\n", strerror(errno));
		rc = 1;
		goto end_of_function;
	}

end_of_function:

    IILC_TRACE_EXIT_RC(rc);
    return rc;
}
