/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#include "trace.h"

#include "cfontz.h"

#define IILC_MODULE MODULE_TYPE_PACKET


int cfontz_InitDevice(LP_CFONTZ_DEV_INSTANCE pInst)
{
    int rc = 0;

    DCB          dcb;
    COMMTIMEOUTS our_timeouts;

    IILC_TRACE_ENTRY(IILC_MODULE, T_cfontz_InitDevice_w32);

    /* Open the USB serial port */
    pInst->Device = CreateFile(pInst->pszPort, GENERIC_READ | GENERIC_WRITE,
        0, NULL, OPEN_EXISTING, 0, NULL);

	if (pInst->Device == INVALID_HANDLE_VALUE) {
        traceDebug(IILC_TRACE_CONTEXT, "Could not open port: %s", strerror(errno));
		rc = 1;
		goto end_of_function;
	}
    
    /*
     * Omit the call to SetupComm to use the default queue sizes.
     * Get the current configuration.
     */
    rc = GetCommState(pInst->Device, &dcb);
    if (!rc) {
        traceDebug(IILC_TRACE_CONTEXT, "Could not get comm state");
        goto end_of_function;
    }

    /* Fill in the DCB: baud=115200, 8 data bits, no parity, 1 stop bit. */
    dcb.BaudRate = 115200;
    dcb.ByteSize = 8;
    dcb.Parity = NOPARITY;
    dcb.StopBits = ONESTOPBIT;
    dcb.fRtsControl = RTS_CONTROL_ENABLE;
    dcb.fDtrControl = DTR_CONTROL_ENABLE; 
    dcb.fAbortOnError = FALSE; 
    
    rc = SetCommState(pInst->Device, &dcb);
    if (!rc) {
        traceDebug(IILC_TRACE_CONTEXT, "Could not set comm state");
        goto end_of_function;
    }

    if (GetCommTimeouts(pInst->Device, &our_timeouts) != TRUE) {
        traceDebug(IILC_TRACE_CONTEXT, "Could not get comm timeouts");
        goto end_of_function;
    }

    /* 9600 is 1 byte per mS. Set it to 2 mS so the read will stay
     * as long as data is coming in. Will wait at least 100mS for
     * the 635 to respond.
     */
    our_timeouts.ReadIntervalTimeout        = 2000;
    our_timeouts.ReadTotalTimeoutMultiplier = 2000;  /* 1 second */
    our_timeouts.ReadTotalTimeoutConstant   = 2000;

    if (SetCommTimeouts(pInst->Device, &our_timeouts) != TRUE) {
        traceDebug(IILC_TRACE_CONTEXT, "Could not set comm timeouts");
        goto end_of_function;
    }

end_of_function:

    IILC_TRACE_EXIT_RC(rc);
    return rc;
}

