/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__PACKET_H__)
#define __PACKET_H__

#include "lcd.h"

/* Maximum amount of data a packet can hold */
#define MAX_DATA_LENGTH 22


typedef struct _tag_packet  * LPPACKET;


typedef enum _tag_packet_type {

    PACKET_TYPE_PING                = 0x00,
    PACKET_TYPE_GET_VERSION_INFO    = 0x01,
    PACKET_TYPE_WRITE_FLASH_AREA    = 0x02,
    PACKET_TYPE_READ_FLASH_AREA     = 0x03,
    PACKET_TYPE_STORE_AS_BOOT       = 0x04,
    PACKET_TYPE_POWER_CONTROL       = 0x05,
    PACKET_TYPE_CLEAR_SCREEN        = 0x06,
 /* DEPRECATED                      = 0x07, */
 /* DEPRECATED                      = 0x08, */
    PACKET_TYPE_SET_CHAR_DATA       = 0x09,
    PACKET_TYPE_READ_LCD_MEMORY     = 0x0A,
    PACKET_TYPE_SET_CURSOR_POS      = 0x0B,
    PACKET_TYPE_SET_CURSOR_STYLE    = 0x0C,
    PACKET_TYPE_SET_LCD_CONTRAST    = 0x0D,
    PACKET_TYPE_SET_BACKLIGHT       = 0x0E,
 /* DEPRECATED                      = 0x0F, */
    PACKET_TYPE_SET_FAN_REPORTING   = 0x10,
    PACKET_TYPE_SET_FAN_POWER       = 0x11,
    PACKET_TYPE_READ_DOW_DEVICE     = 0x12,
    PACKET_TYPE_SET_TEMP_REPORTING  = 0x13,
    PACKET_TYPE_DOW_TRANSACTION     = 0x14,
 /* DEPRECATED                      = 0x15, */
    PACKET_TYPE_DIRECT_LCD_CMD      = 0x16,
    PACKET_TYPE_SET_KEY_REPORTING   = 0x17,
    PACKET_TYPE_READ_KEY_STATE      = 0x18,
    PACKET_TYPE_SET_FAN_FAILSAFE    = 0x19,
    PACKET_TYPE_SET_FAN_TACH_GLITCH = 0x1A,
    PACKET_TYPE_GET_FAN_FAILSAFE    = 0x1B,
    PACKET_TYPE_SET_ATX_POWER_SW    = 0x1C,
    PACKET_TYPE_MANAGE_WATCHDOG     = 0x1D,
    PACKET_TYPE_REPORTING_STATUS    = 0x1E,
    PACKET_TYPE_WRITE_DATA          = 0x1F,
 /* RESERVED                        = 0x20, */
    PACKET_TYPE_SET_BAUD_RATE       = 0x21,
    PACKET_TYPE_SET_GPIO            = 0x22,
    PACKET_TYPE_GET_GPIO            = 0x23,
    PACKET_TYPE_RPT_KEY_ACTIVITY    = 0x80,
    PACKET_TYPE_RPT_FAN_SPEED       = 0x81,
    PACKET_TYPE_RPT_TEMP_SENSOR     = 0x82

} PACKET_TYPE;

typedef enum _tag_packet_class {

    PACKET_CLASS_NORMAL_REQUEST      = 0x00,
    PACKET_CLASS_NORMAL_RESPONSE     = 0x01,
    PACKET_CLASS_NORMAL_REPORT       = 0x02,
    PACKET_CLASS_ERROR_RESPONSE      = 0x03

} PACKET_CLASS;


LCD_API int packetCreate(PACKET_TYPE type,
                         LPPACKET * ppPacket);

LCD_API int packetDispose(LPPACKET * ppPacket);

LCD_API int packetReadData(LPPACKET pPacket,
                           unsigned char * data);

LCD_API int packetReadReset(LPPACKET pPacket);

LCD_API int packetWriteData(LPPACKET pPacket,
                            unsigned char data);

LCD_API int packetWriteString(LPPACKET pPacket,
                              char * strData,
                              int strDataLen);

LCD_API int packetGetClass(LPPACKET pPacket);

LCD_API int packetGetType(LPPACKET pPacket,
                          PACKET_TYPE * pType);


/* ---------------------------------------------------------------
 * Callbacks used to transform packets to & from the wire format
 * --------------------------------------------------------------- */

LCD_API int packetFlatten(LPPACKET pPacket,
                          unsigned char * buf,
                          int * pDataLen);

LCD_API int packetInflate(unsigned char * buf,
                          int bufLen,
                          int * pBytesRead,
                          LPPACKET * ppPacket);


#endif /* __PACKET_H__ */
