/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#include "hddTemp.h"


typedef struct _tag_screen_temp
{
    double temp;


} SCREEN_TEMP, * LPSCREEN_TEMP;


void temperatureReport(void * context,
                       unsigned int sensor_id,
                       double degrees_c,
                       const char * pszName);

int ModuleCreate(int handle, void ** context, LPMODULE_FN_ARRAY pFnArray)
{
    LPSCREEN_TEMP pInst = NULL;

    /* Create our own scratch space */
    pInst = malloc(sizeof(SCREEN_TEMP));
    *context = pInst;

    /* We can use fn array version 1 */
    pFnArray->version = 1;

    /* Setup our various functions */
    pFnArray->pfnTextData = GetDisplayData;
    pFnArray->pfnTempReport = temperatureReport;

    return 0;
}


int ModuleDestroy(void * context)
{
    LPSCREEN_TEMP pInst = (LPSCREEN_TEMP) context;

    /* Release the scratch storage array */
    free(pInst);

    return 0;
}


int GetDisplayData(void * context, LPSCREEN pScreen, char ** buf)
{
    LPSCREEN_TEMP pInstance = (LPSCREEN_TEMP) context;

    sprintf(*buf, "%.1f%cC", pInstance->temp, 0x80);
    
    return 0;
}

void temperatureReport(void * context, unsigned int sensor_id, double degrees_c, const char * pszName)
{
    LPSCREEN_TEMP pInst = (LPSCREEN_TEMP) context;

    pInst->temp = degrees_c;
}
