/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#include <time.h>

#if defined(_WIN32)
#else
#   include <strings.h>
#endif

#include "scrLED.h"

typedef struct _tag_screen_fans
{
    /** Number of fans being monitored */
    unsigned int fanCount;

    /** Array of unsigned ints to contain rpm values */
    unsigned int * rpmList;

} SCREEN_FANS, * LPSCREEN_FANS;


/* ----- Internal function definitions ----- */


int fanSpeedReport(void * context, 
                   unsigned int fan_id, 
                   unsigned int fan_speed);


/* ----- Implementation ----- */



int ModuleCreate(int handle, void ** context, LPMODULE_FN_ARRAY pFnArray)
{
    int rc = 0;

    LPSCREEN_FANS pInst = NULL;

    /* Create our own scratch space */
    pInst = malloc(sizeof(SCREEN_FANS));
    if (pInst == NULL) {
        printf("malloc() failed in Fans module create");
        rc = -1;
        goto end_of_function;
    }

    /* Default to looking after one fan */
    pInst->fanCount = 1;

    /* Zero out the array contents */
    pInst->rpmList = calloc(pInst->fanCount, sizeof(unsigned int));

    /* --- Populate the function array data --- */

    /* We can use fn array version 1 */
    pFnArray->version = 1;

    /* Setup our various functions */
    pFnArray->pfnTextData = GetDisplayData;
    pFnArray->pfnReadLEDStatus = GetLEDStatus;

    /* --- */

    /* Return context data back to the caller */
    *context = pInst;

end_of_function:

    return rc;
}


int ModuleDestroy(void * context)
{
    LPSCREEN_FANS pInst = (LPSCREEN_FANS) context;

    free(pInst);

    return 0;
}


int GetDisplayData(void * context, LPSCREEN pScreen, char ** buf)
{
    LPSCREEN_FANS pInstance = (LPSCREEN_FANS) context;

    char * lfChar = NULL;
 
    /* Grab the last fan report we received */
    sprintf(*buf, "FAN %u: %u RPM", 0, pInstance->rpmList[0]);
    
    return 0;
}

int GetLEDStatus(void * context, unsigned int led_id,
                 LPCOLOUR pColourOn, LPCOLOUR pColourOff,
                 unsigned int * pDutyCycle, unsigned int * pFreq)
{
    SET_COLOUR(pColourOn, 100, 0, 0);
    SET_COLOUR(pColourOff,  0, 100, 0);
    
    /* Simple 50% on, 50% off */
    *pDutyCycle = 50;

    /* Reasonably slow flash rate (1 Hz) */
    *pFreq = 50 + (25 * led_id);

    return 0;
}

