/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#include "trace.h"

#include "scrTemp.h"


#define IILC_MODULE MODULE_TYPE_DISPLAY


typedef struct _tag_screen_temp
{
    double temp;

    const char * pszName;

} SCREEN_TEMP, * LPSCREEN_TEMP;


void temperatureReport(void * context,
                       unsigned int sensor_id,
                       double degrees_c,
                       const char * pszName);

void fanSpeedReport(void * context, 
                    unsigned int fan_id, 
                    unsigned int fan_speed, 
                    const char * pszName);


int ModuleCreate(int handle, void ** context, LPMODULE_FN_ARRAY pFnArray)
{
    LPSCREEN_TEMP pInst = NULL;

    /* Create our own scratch space */
    pInst = malloc(sizeof(SCREEN_TEMP));
    *context = pInst;

    /* We can use fn array version 1 */
    pFnArray->version = 1;

    /* Setup our various functions */
    pFnArray->pfnTextData = GetDisplayData;
    pFnArray->pfnTempReport = temperatureReport;
    pFnArray->pfnFanSpeedReport = fanSpeedReport;

    return 0;
}


int ModuleDestroy(void * context)
{
    LPSCREEN_TEMP pInst = (LPSCREEN_TEMP) context;

    /* Release the scratch storage array */
    free(pInst);

    return 0;
}


int GetDisplayData(void * context, int nRow, int nWidth, char * buf)
{
    LPSCREEN_TEMP pInstance = (LPSCREEN_TEMP) context;

    sprintf(buf, "%.1f%cC", pInstance->temp, 0x80);
    
    return 0;
}

void temperatureReport(void * context, unsigned int sensor_id, double degrees_c, const char * pszName)
{
    LPSCREEN_TEMP pInst = (LPSCREEN_TEMP) context;

    IILC_TRACE_ENTRY(IILC_MODULE, T_temperatureReport);
    traceDebug(IILC_TRACE_CONTEXT, 
        "pInst %p, sensor_id %u, degrees_c %f", pInst, sensor_id, degrees_c);

    pInst->temp = degrees_c;
    pInst->pszName = pszName;

    traceInfo(IILC_TRACE_CONTEXT, "(TEMP) Temperature report for sensor [%10s] at %.0fC", pszName, degrees_c);

    IILC_TRACE_EXIT;
}


void fanSpeedReport(void * context, unsigned int fan_id, unsigned int fan_speed, const char * pszName)
{
    IILC_TRACE_ENTRY(IILC_MODULE, T_fanSpeedReport);

    fan_speed = (((fan_speed * 2) + 5) / 10) * 5;

    traceInfo(IILC_TRACE_CONTEXT, "(TEMP) Fan speed report of sensor    [%10s] at %u RPM", pszName, fan_speed);
    
    IILC_TRACE_EXIT;
}

