/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__CONFIG_H__)
#define __CONFIG_H__

#include "lcd.h"

enum displayObjectType
{
    OBJECT_TYPE_FAN,
    OBJECT_TYPE_LED,
    OBJECT_TYPE_TEMP
};


typedef struct _tag_config_object  * LPCONFIG_OBJECT;
typedef struct _tag_config_module  * LPCONFIG_MODULE;
typedef struct _tag_config_device  * LPCONFIG_DEVICE;
typedef struct _tag_config_display * LPCONFIG_DISPLAY;
typedef struct _tag_config_screen  * LPCONFIG_SCREEN;
typedef struct _tag_config_window  * LPCONFIG_WINDOW;
typedef struct _tag_config_file    * LPCONFIG_FILE;




/****************************************************************************/
/*                                                                          */
/* Config file functions                                                    */
/*                                                                          */
/****************************************************************************/

LCD_API int configFileCreate(LPCONFIG_FILE * ppFile,
                             const char * pszName);

LCD_API int configFileAddDisplay(LPCONFIG_FILE pFile,
                                 LPCONFIG_DISPLAY pDisplay);

LCD_API int configFileGetDisplayCount(LPCONFIG_FILE pConfig, 
                                      int * pnCount);

LCD_API int configFileGetDisplay(LPCONFIG_FILE pFile,
                                 int nIndex,
                                 LPCONFIG_DISPLAY * ppDisplay);

LCD_API int configFileValidate(LPCONFIG_FILE pFile);

LCD_API int configFileDispose(LPCONFIG_FILE * ppFile);

//LCD_API int configFileGetModuleCount(LPCONFIG_FILE pConfig, 
//                                     int nDisplayIndex, 
//                                     int * pnCount);

/****************************************************************************/
/*                                                                          */
/* Config display functions                                                 */
/*                                                                          */
/****************************************************************************/

LCD_API int configDisplayCreate(LPCONFIG_DISPLAY * ppDisplay,
                                const char * pszDisplay);

LCD_API int configDisplaySetDevice(LPCONFIG_DISPLAY pDisplay,
                                   LPCONFIG_DEVICE pDevice);

LCD_API int configDisplayAddModule(LPCONFIG_DISPLAY pDisplay,
                                   LPCONFIG_MODULE pModule);

LCD_API int configDisplayAddScreen(LPCONFIG_DISPLAY pDisplay,
                                   LPCONFIG_SCREEN pScreen);

LCD_API int configDisplayGetDevice(LPCONFIG_DISPLAY pDisplay,
                                   LPCONFIG_DEVICE * ppDevice);

LCD_API int configDisplayGetModuleCount(LPCONFIG_DISPLAY pDisplay,
                                        int * pnCount);

LCD_API int configDisplayGetModule(LPCONFIG_DISPLAY pDisplay,
                                   int index,
                                   LPCONFIG_MODULE * ppModule);

LCD_API int configDisplayGetScreenCount(LPCONFIG_DISPLAY pDisplay,
                                        int * pnCount);

LCD_API int configDisplayGetScreen(LPCONFIG_DISPLAY pDisplay,
                                   int nIndex,
                                   LPCONFIG_SCREEN * ppScreen);

LCD_API int configDisplayDispose(LPCONFIG_DISPLAY * ppDisplay);

//LCD_API int configGetDisplayDeviceIndex(LPCONFIG_FILE pConfig,
//                                int nDisplayIndex, 
//                                int * nDeviceIndex);

//LCD_API int configDisplayGetDescr(LPCONFIG_DISPLAY pDisplay, 
//                                  const char ** ppszDescr);

/****************************************************************************/
/*                                                                          */
/* Config device functions                                                  */
/*                                                                          */
/****************************************************************************/

LCD_API int configDeviceCreate(LPCONFIG_DEVICE * ppDevice,
                               const char * pszName);

LCD_API int configDeviceUseObject(LPCONFIG_DEVICE pDevice,
                                  enum displayObjectType type,
                                  int physical_id,
                                  const char * pszName);

LCD_API int configDeviceSetClass(LPCONFIG_DEVICE pDevice,
                                 const char * pszClass);

LCD_API int configDeviceSetPort(LPCONFIG_DEVICE pDevice,
                                const char * pszPort);

LCD_API int configDeviceGetName(LPCONFIG_DEVICE pDevice, 
                                const char ** ppszName);

LCD_API int configDeviceGetClass(LPCONFIG_DEVICE pDevice, 
                                 char ** ppszClass);

LCD_API int configDeviceGetPort(LPCONFIG_DEVICE pDevice, 
                                char ** ppszPort);

LCD_API int configDeviceDispose(LPCONFIG_DEVICE * ppDevice);

/****************************************************************************/
/*                                                                          */
/* Config module functions                                                  */
/*                                                                          */
/****************************************************************************/

LCD_API int configModuleCreate(LPCONFIG_MODULE * ppModule,
                               const char * pszModule);


LCD_API int configModuleControlObject(LPCONFIG_MODULE pModule,
                                      enum displayObjectType type,
                                      int object_id);

LCD_API int configModuleReportObject(LPCONFIG_MODULE pModule,
                                     enum displayObjectType type,
                                     int object_id,
                                     const char * pszReportAs);

LCD_API int configModuleVirtualObject(LPCONFIG_MODULE pModule,
                                      int module_id,
                                      int device_id,
                                      const char * pszObject);

LCD_API int configModuleSetLibrary(LPCONFIG_MODULE pModule,
                                   const char * pszLibrary);

LCD_API int configModuleGetLibrary(LPCONFIG_MODULE pModule, 
                                   const char ** ppszName);

LCD_API int configModuleGetReportCount(LPCONFIG_MODULE pModule,
                                       int * pnCount);

LCD_API int configModuleGetReportObject(LPCONFIG_MODULE pModule,
                                        int index,
                                        LPCONFIG_OBJECT * ppObject);

LCD_API int configModuleDispose(LPCONFIG_MODULE * ppModule);

/****************************************************************************/
/*                                                                          */
/* Config screen functions                                                  */
/*                                                                          */
/****************************************************************************/

LCD_API int configScreenCreate(LPCONFIG_SCREEN * ppScreen,
                               const char * pszScreen);

LCD_API int configScreenShowModule(LPCONFIG_SCREEN pScreen,
                                   const char * pszModule,
                                   int size_x, 
                                   int size_y,
                                   int pos_x,
                                   int pos_y);

LCD_API int configScreenGetWindowCount(LPCONFIG_SCREEN pScreen,
                                       int * pnCount);

LCD_API int configScreenGetWindow(LPCONFIG_SCREEN pScreen,
                                  int nIndex,
                                  LPCONFIG_WINDOW * ppWindow);

/****************************************************************************/
/*                                                                          */
/* Config window functions                                                  */
/*                                                                          */
/****************************************************************************/

LCD_API int configWindowCreate(LPCONFIG_WINDOW * ppWindow,
                               int width,
                               int height,
                               int x,
                               int y,
                               const char * pszModule);

LCD_API int configWindowGetLocation(LPCONFIG_WINDOW pWindow,
                                    int * pnX,
                                    int * pnY);

LCD_API int configWindowGetSize(LPCONFIG_WINDOW pWindow,
                                int * pnWidth,
                                int * pnHeight);

LCD_API int configWindowGetModuleName(LPCONFIG_WINDOW pWindow,
                                      const char ** ppszModuleName);

LCD_API int configWindowDispose(LPCONFIG_WINDOW * ppWindow);

/****************************************************************************/
/*                                                                          */
/* Config object functions                                                  */
/*                                                                          */
/****************************************************************************/


LCD_API int configObjectGetId(LPCONFIG_OBJECT pObject,
                              unsigned int * pnId);

LCD_API int configObjectGetName(LPCONFIG_OBJECT pObject,
                                char ** pszName);

LCD_API int configObjectGetType(LPCONFIG_OBJECT pObject,
                                enum displayObjectType * pType);



#endif

