/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !(defined __DISPLAY_H__)
#define __DISPLAY_H__

#include "lcd.h"
#include "module.h"
#include "screen.h"

typedef struct _tag_display * LPDISPLAY;

typedef void (* pfnDspCBFanSpeed)(void * context,
                                  unsigned int fan_id,
                                  const char * pszFanName,
                                  unsigned int rpm);

typedef void (* pfnDspCBTemp)(void * context,
                              unsigned int sensor_id,
                              double degrees_c);

typedef void (* pfnDspCBKeyEvent)(void * context,
                                  unsigned int key_event);


LCD_API int displayCreate(const char * pszClass,
                          const char * pszPort,
                          LPDISPLAY * ppDisplay);

LCD_API int displayOpen(LPDISPLAY pDisplay);

LCD_API int displayClose(LPDISPLAY pDisplay);

LCD_API int displayDispose(LPDISPLAY * ppDisplay);

LCD_API int displayGetSize(LPDISPLAY pDisplay,
                           int * width,
                           int * height);

LCD_API int displayAddFanReportListener(LPDISPLAY pDisplay, 
                                        unsigned int fan_id,
                                        LPMODULE pModule,
                                        const char * pszName);

LCD_API int displayAddTempReportListener(LPDISPLAY pDisplay,
                                         unsigned int sensor_id,
                                         LPMODULE pModule,
                                         const char * pszName);

LCD_API int displayScreenAdd(LPDISPLAY pDisplay,
                             LPSCREEN pScreen);

/*

LCD_API int displaySetKeyEventListener(LPDISPLAY pDisplay, 
                                       pfnKeyEventListener pfnListener,
                                       void * context);
*/
int displayStart(LPDISPLAY pDisplay);

int displayStop(LPDISPLAY pDisplay);



#endif /* __DISPLAY_H__ */

