/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__EVENTQUEUE_H__)
#define __EVENTQUEUE_H__

#include "lcd.h"

typedef struct _tag_event_queue * LPEVENT_QUEUE;

typedef enum _tag_event_type
{
    EVENT_NOT_DEFINED,
    EVENT_NO_OP,
    EVENT_TEXT_SCROLL,
    EVENT_KEY_PRESS,
    EVENT_KEY_RELEASE,
    EVENT_LED_UPDATE,
    EVENT_SCREEN_CLEAR,
    EVENT_SCREEN_CHANGE,
    EVENT_SCREEN_REFRESH,
    EVENT_SET_BACKLIGHT,
    EVENT_ENABLE_TEMP_REPORT,
    EVENT_DISABLE_TEMP_REPORT,
    EVENT_ENABLE_FAN_REPORT,
    EVENT_DISABLE_FAN_REPORT,
    EVENT_SET_FAN_STATE,
    EVENT_SHUTDOWN,
    EVENT_POLL_MODULE,
    EVENT_SET_CONTRAST,
    EVENT_POLL_LED_STATUS,

} EVENT_TYPE, * LPEVENT_TYPE;


typedef struct _tag_event
{
    EVENT_TYPE eType;

    void * pData;

    unsigned int iData;
    
} EVENT, * LPEVENT;


#define EVENT_INIT(evt,e,p,i) { (evt).eType = (e); (evt).pData = (p); (evt).iData = (i); }


LCD_API int eventQueueCreate(LPEVENT_QUEUE * ppEventQueue);

LCD_API int eventQueueDispose(LPEVENT_QUEUE * ppEventQueue);

LCD_API int eventQueueEnqueue(LPEVENT_QUEUE pEventQueue,
                              LPEVENT pEvent,
                              unsigned int fireInMillis);

LCD_API int eventQueueDequeue(LPEVENT_QUEUE pEventQueue,
                              LPEVENT pEvent);


#endif /* __EVENTQUEUE_H__ */

