%{
#include <stdio.h>
#include "parserImpl.h"
%}

%union
{
	struct {
		int x;
		int y;
	} coord;

	int number;
	char * str;
}


%token OBRACE
%token EBRACE
%token QUOTE
%token SEMICOLON
%token DISPLAY    
%token DEVICE    
%token MODULE
%token LIBRARY
%token CONTROL
%token LED
%token TEMP
%token CLASS
%token PORT
%token REPORT
%token USE
%token FAN
%token AS 
%token NAMED
%token SCREEN
%token AT
%token SHOW
%token SIZE_KW
%token COMMA
%token VIRTUAL

%token <str> STRING
%token <number> INTEGER

%type <number> entity

/* A point is a co-ordinate pair */
%type <coord> point

%error-verbose

%%

file:
	  /* empty */
	| file display
;


display:
	DISPLAY STRING 
		{ parserDisplayBegin($2); }
		OBRACE display_body EBRACE
		{ parserDisplayEnd(); }
;

display_body:
	  /* empty */
	| display_body screen
	| display_body module
	| display_body device
;

device:
	DEVICE STRING
		{ parserDeviceBegin($2); }
		OBRACE device_body EBRACE
		{ parserDeviceEnd(); }
;

device_body:
	  /* empty */
	| device_body CLASS STRING SEMICOLON
		{ parserDeviceSetClass($3); }
	| device_body PORT STRING SEMICOLON
		{ parserDeviceSetPort($3); }
	| device_body USE entity INTEGER SEMICOLON
		{ parserDeviceObjectUse($3, $4, NULL); }
	| device_body USE entity INTEGER NAMED STRING SEMICOLON
		{ parserDeviceObjectUse($3, $4, $6); }
;

module:
	MODULE STRING
		{ parserModuleBegin($2); }
		OBRACE module_body EBRACE
		{ parserModuleEnd(); }
;

entity:
		TEMP { $$ = OBJECT_TYPE_TEMP; }
	|	LED  { $$ = OBJECT_TYPE_LED; }
	|	FAN  { $$ = OBJECT_TYPE_FAN; }
;

screen:
	SCREEN STRING
		{ parserScreenBegin($2); }
		OBRACE screen_body EBRACE
		{ parserScreenEnd(); }
;

screen_body:
	  /* empty */
	| screen_body SHOW STRING SEMICOLON                         /* Module occupies all of the screen */
		{ parserScreenShowModule($3, -1, -1, -1, -1); }
	| screen_body SHOW STRING SIZE_KW point SEMICOLON           /* Module is of specific size at (0,0) */
		{ parserScreenShowModule($3, $5.x, $5.y, -1, -1); }
	| screen_body SHOW STRING SIZE_KW point AT point SEMICOLON /* Module is of specific size at specific location */
		{ parserScreenShowModule($3, $5.x, $5.y, $7.x, $7.y); }
;

point:
	INTEGER COMMA INTEGER 
		{ $$.x = $1, $$.y = $3; }
;

module_body:
	  /* empty */
	| module_body LIBRARY STRING SEMICOLON
		{ parserModuleSetLibrary($3); }
	| module_body CONTROL entity INTEGER SEMICOLON
		{ parserModuleControlObject($3, $4); }
	| module_body REPORT entity INTEGER SEMICOLON
		{ parserModuleReportObject($3, $4, NULL); }
	| module_body REPORT entity INTEGER NAMED STRING SEMICOLON
		{ parserModuleReportObject($3, $4, $6); }
	| module_body VIRTUAL TEMP INTEGER AS INTEGER SEMICOLON
		{ parserModuleVirtualObject($4, $6, NULL); }
	| module_body VIRTUAL TEMP INTEGER AS INTEGER NAMED STRING SEMICOLON
		{ parserModuleVirtualObject($4, $6, $8); }
;

%%


int yyerror(char * s)
{
	printf("Error: %s\n", s);
	return -1;
}


