/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#if !defined(__PARSER_H__)
#define __PARSER_H__

#include "lcd.h"
#include "config.h"

#define PARSER_MODULE_ENTITY_FAN   1
#define PARSER_MODULE_ENTITY_TEMP  2
#define PARSER_MODULE_ENTITY_LED   3


int yyparse(void);

int yylex(void);

int yyerror(char * err);

int parserParse(LPCONFIG_FILE * ppFile,
                const char * pszFileName);

/* ------------------------------------------------------------------------ */
/*                                                                          */
/* Functions used by the parser to read in the configuration                */
/*                                                                          */
/* ------------------------------------------------------------------------ */

/* ----------------- Device entity ----------------- */

void parserDeviceBegin(char * pszDevice);

void parserDeviceSetClass(char * pszClass);

void parserDeviceSetPort(char * pszPort);

int  parserDeviceObjectCreate(int object_id, 
                              char * pszName, 
                              enum displayObjectType type, 
                              LPCONFIG_OBJECT * ppObject);

int parserDeviceObjectFind(LPCONFIG_DEVICE pDevice, 
                           enum displayObjectType type,
                           int object_id,
                           LPCONFIG_OBJECT * ppObject);

void parserDeviceObjectUse(enum displayObjectType type,
                           int id,
                           char * pszName);

void parserDeviceEnd(void);


/* ----------------- Display entity ----------------- */

void parserDisplayBegin(const char * pszDisplay);

void parserDisplayEnd();

void parserDisplaySetDevice(const char * pszDevice);



/* ----------------- Module entity ----------------- */

void parserModuleBegin(char * pszModule);

void parserModuleSetLibrary(char * pszLibrary);

void parserModuleControlObject(enum displayObjectType object_type, 
                               int object_id);

void parserModuleReportObject(enum displayObjectType object_type, 
                              int object_id, 
                              const char * report_as);

void parserModuleVirtualObject(int module_id,
                               int device_id,
                               const char * pszObject);

void parserModuleEnd();



/* ----------------- Screen entity ----------------- */



void parserScreenBegin(char * pszScreen);

void parserScreenEnd(void);

void parserScreenShowModule(char * pszModule,
                            int size_x,
                            int size_y,
                            int pos_x,
                            int pos_y);


#endif

