%{
#include <stdio.h>
#include <string.h>
#include "y.tab.h"

int prevState;

#define TOK_EOF 0

%}

%option noyywrap 
%x C_COMMENT

%%

"/*" {
	/* C-style comments */
	prevState = YY_START;
	BEGIN(C_COMMENT);
}

<C_COMMENT>{
	"*/" {
		/* end of comment */
		BEGIN(prevState);
  	}

	. {
    	/* anything but slash-star or newline -- eat it */
	}

	"\n" { /* chomp */ }
    
	<<EOF>> {
	    printf("Error: unterminated comment\n");
    	return TOK_EOF;
	}
}



device					return DEVICE;
display					return DISPLAY;
module					return MODULE;
use						return USE;
library					return LIBRARY;
report					return REPORT;
control					return CONTROL;
virtual					return VIRTUAL;
screen					return SCREEN;
show					return SHOW;
at						return AT;
size					return SIZE_KW;

fan						return FAN;
temp					return TEMP;
led						return LED;

as						return AS;
named					return NAMED;
class					return CLASS;
port					return PORT;

						/* Chop the leading and trailing quote chars from the string */
\"[^\"]*\"				yylval.str = strdup(&yytext[1]); yylval.str[strlen(yytext)-2] = '\0'; return STRING;

0|[1-9][0-9]*			yylval.number = atoi(yytext); return INTEGER;


\/\/.*\n					/* ignore */ ; /* { printf("C++ comment\n"); } */

\"                      return QUOTE;
\{                      return OBRACE;
\}                      return EBRACE;
\;                      return SEMICOLON;
,						return COMMA;
\r                      /* ignore EOL */;
\n                      /* ignore EOL */;
[ \t]+                  /* ignore whitespace */;


%%

