/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 * 
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#include "lcd.h"
#include "screen.h"
#include "module.h"
#include "string.h"
#include "vector.h"

/**
  * \brief Structure used to store various bits of information about the
  *        position and size of a window within a given screen.
  */
typedef struct _tag_window
{
    int x;

    int y;

    int width;

    int height;

    LPMODULE pModule;

} WINDOW, * LPWINDOW;

/*

typedef struct _tag_window
{
    unsigned int x;

    unsigned int y;

    unsigned int width;

    unsigned int height;

    WINDOW_TYPE type;

    union _tag_window_pfn {
        pfnGetTextData    GetText;
        pfnGetNumericData GetNumeric;
    } pfn;

    void * context;

} WINDOW;

*/

typedef enum
{
    SCREEN_TYPE_TEXT,
    SCREEN_TYPE_BAR

} SCREEN_TYPE;

typedef struct _tag_screen
{
    int type;

    int width;

    int height;

    LPVECTOR pWindowList;

} SCREEN;

int screenGetSize(LPSCREEN pScreen, int * width, int * height)
{
    *width = pScreen->width;
    *height = pScreen->height;

    return 0;
}


int screenCreate(LPSCREEN * ppScreen, unsigned int uWidth, unsigned int uHeight)
{
    int rc = 0;
    LPSCREEN pScreen = NULL;

    pScreen = calloc(1, sizeof(SCREEN));
    pScreen->height = uHeight;
    pScreen->width  = uWidth;

    vectorCreate(&(pScreen->pWindowList));

    /* Assign to user */
    *ppScreen = pScreen;

    return rc;
}


int screenAddWindow(LPSCREEN pScreen, int x, int y, int width, int height, LPMODULE pModule)
{
    int rc = 0;
    LPWINDOW pWindow = NULL;

    pWindow = (LPWINDOW) calloc(1, sizeof(WINDOW));
    pWindow->x       = x;
    pWindow->y       = y;
    pWindow->width   = width;
    pWindow->height  = height;
    pWindow->pModule = pModule;

    vectorAdd(pScreen->pWindowList, pWindow);

    return rc;
}



int screenDoRender(LPSCREEN pScreen, char * pszScreen)
{
    int rc = 0;
    int i = 0, w = 0;
    int nWindowCount = 0;
    int nScreenSize = 0;

    /* Calculate our screen size and clear data to spaces */
    nScreenSize = pScreen->width * pScreen->height;
    memset(pszScreen, ' ', nScreenSize);

    /* Find number of windows in this screen */
    vectorGetSize(pScreen->pWindowList, &nWindowCount);
    for (w = 0; w < nWindowCount; w++) {

        LPWINDOW pWindow = NULL;
        int windowY = 0;

        /* Offset into the main buffer */
        int offset = 0;

        vectorGetElementAt(pScreen->pWindowList, w, (void **) &pWindow);

        /* Initialise offset */
        offset = pWindow->x + (pWindow->y * pScreen->width);

        /* Render the window line by line */
        for (windowY = 0; windowY < pWindow->height; windowY++) {

            /* Local temp buffer (TODO: Stack overwrite potential!) */
            char buf[1024];
            memset(buf, 0, sizeof(buf));

            /* Get data from the module */
            moduleRender(pWindow->pModule, windowY, pWindow->width, buf);

            /* Copy up to the last null-terminator */
            for (i = 0; (i < pWindow->width) && (buf[i] != 0); i++) {
                pszScreen[offset + i] = buf[i];
            }

            /* Increate offset into the main buffer */
            offset += pScreen->width;
        }

        // printf("Screen rendered as [%s]\n", pszScreen);
    }

    return rc;
}


void * RenderThread(void * arg)
{
    int running = 0;

    printf("RenderThread\n");

    while (running)
    {


    }

    return NULL;
}
